@echo off
REM
REM Script: esilo_backup_mysql.cmd
REM Version: 1.0.0
REM  
REM Purpose: Perform a MySQL database backup and prepare the folder to be
REM backed up by eSilo
REM
REM Supported operating environments:
REM
REM MySQL 5.0
REM

REM ************* CONFIGURATION START *************

set MYSQL_BIN_DIR=C:\Program Files\MySQL\MySQL Server 5.0\bin
set SCRIPT_DIR=C:\eSilo_MySQL_Backups
set DESTINATION=C:\eSilo_MySQL_Backups

set DATABASE=eSiloTest
set USERNAME=root
set PASSWORD=eSilo1234


REM Split size must be 64 GiB or less

REM 64 GiB
REM set SPLIT_SIZE=68719476736

REM 32 GiB
set SPLIT_SIZE=34359738368

REM 700 MiB for CD-Rs
REM set SPLIT_SIZE=734003200


REM ************* CONFIGURATION END *************


set LOG=%DESTINATION%\%DATABASE%.log
SET TEE=%SCRIPT_DIR%\wtee.exe

echo:>%LOG%

echo %DATE% %TIME% ] Starting esilo_backup_mysql script. | %TEE% -a %LOG%

if not exist "%MYSQL_BIN_DIR%\mysqldump.exe" goto mysqldump_missing
goto mysqldump_exists
:mysqldump_missing
echo FATAL: mysqldump.exe does not exist at: %MYSQL_BIN_DIR%\mysqldump.exe | %TEE% -a %LOG%
eventcreate /l Application /t ERROR /so "eSilo MySQL Backup Script" /id 1 /d "eSilo MySQL Backup Script Failed: mysqldump.exe does not exist at: %MYSQL_BIN_DIR%\mysqldump.exe" 2>&1 | %TEE% -a %LOG%
exit /b 2
:mysqldump_exists
echo mysqldump.exe exists at: %MYSQL_BIN_DIR%\mysqldump.exe | %TEE% -a %LOG%
echo Running mysqldump...  | %SCRIPT_DIR%\wtee.exe -a %LOG%
"%MYSQL_BIN_DIR%\mysqldump.exe" --user=%USERNAME% --password=%PASSWORD% %DATABASE% > %DESTINATION%\%DATABASE%.sql 2> %DESTINATION%\mysqldump.output.txt
if %ERRORLEVEL%. == 0. goto ok
echo mysqldump failed. See output below:  | %TEE% -a %LOG%
type %DESTINATION%\mysqldump.output.txt | %TEE% -a %LOG%
eventcreate /l Application /t ERROR /so "eSilo MySQL Backup Script" /id 1 /d "eSilo MySQL Backup Script Failed: MySQL's mysqldump failed. See log file '%LOG%' for details." 2>&1 | %TEE% -a %LOG%
exit /b 1
:ok
echo mysqldump succeeded. | %TEE% -a %LOG%




REM Split backup file to ensure it is less than 64 GiB in size
echo Splitting file into sizes of %SPLIT_SIZE% bytes or less... | %TEE% -a %LOG%

echo Splitting %DESTINATION%\%DATABASE%.sql ... | %TEE% -a %LOG%
%SCRIPT_DIR%\split.exe -a 3 -d -b %SPLIT_SIZE% %DESTINATION%\%DATABASE%.sql %DESTINATION%\%DATABASE%.sql.  2>&1 | %TEE% -a %LOG%
IF NOT "%ERRORLEVEL%" == "0" goto spliterror
IF NOT EXIST %DESTINATION%\%DATABASE%.sql.000 goto spliterror
del /Q %DESTINATION%\%DATABASE%.sql | %TEE% -a %LOG%

goto splitok

:spliterror

echo ERROR: Split failed. | %TEE% -a %LOG%
eventcreate /l Application /t ERROR /so "eSilo MySQL Backup Script" /id 1 /d "eSilo MySQL Backup Script Failed: Splitting of backup file failed." 2>&1 | %TEE% -a %LOG%
exit /b 1

:splitok
echo Succeeded. | %TEE% -a %LOG%


:done
echo %DATE% %TIME% ] eSilo MySQL Backup Script completed successfully. | %TEE% -a %LOG%
eventcreate /l Application /t INFORMATION /so "eSilo Windows Backup Script" /id 1 /d "eSilo Windows Backup Script Completed Successfully." 2>&1 | %TEE% -a %LOG%



exit /b 0
